@@ -1,25 +1,25 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2003, 2004, 2005 Mondru AB.
  * Copyright (C) 2007-2012 David Bird (Coova Technologies) <support@coova.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
-#ifndef _LIMITS_H
-#define _LIMITS_H
+#ifndef _CHILLI_LIMITS_H
+#define _CHILLI_LIMITS_H
 
 /*
  * extracted from various .h files, needs some cleanup.
@@ -86,11 +86,11 @@
 #define RADIUS_MD5LEN                     16 /* Length of MD5 hash */
 #define RADIUS_AUTHLEN                    16 /* RFC 2865: Length of authenticator */
 #define RADIUS_PWSIZE                    128 /* RFC 2865: Max 128 octets in password */
-#define RADIUS_CHAPSIZE                   24 
+#define RADIUS_CHAPSIZE                   24
 #define RADIUS_QUEUESIZE                 256 /* Same size as id address space */
 #define RADIUS_ATTR_VLEN                 253
 #define RADIUS_HDRSIZE                    20
-#define RADIUS_MPPEKEYSSIZE               32 /* Length of MS_CHAP_MPPE_KEYS attribute */ 
+#define RADIUS_MPPEKEYSSIZE               32 /* Length of MS_CHAP_MPPE_KEYS attribute */
 
 #define UAMSERVER_MAX                      8
 
