@@ -1,24 +1,23 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2007-2012 David Bird (Coova Technologies) <support@coova.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #include "chilli.h"
-#include "debug.h"
 
 #if defined(ENABLE_CHILLIPROXY) || defined(ENABLE_CHILLIRADSEC) || defined(ENABLE_CHILLIREDIR)
 
@@ -30,7 +29,7 @@ int conn_sock(struct conn_t *conn, struct in_addr *addr, int port) {
   server.sin_family = AF_INET;
   server.sin_port = htons(port);
   server.sin_addr.s_addr = addr->s_addr;
-  
+
   if ((sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) > 0) {
 
 #if(_debug_)
@@ -38,15 +37,15 @@ int conn_sock(struct conn_t *conn, struct in_addr *addr, int port) {
 #endif
 
     if (ndelay_on(sock) < 0) {
-      log_err(errno, "could not set non-blocking");
+      syslog(LOG_ERR, "%s: could not set non-blocking", strerror(errno));
     }
 
-    if (safe_connect(sock, 
-		     (struct sockaddr *) &server, 
+    if (safe_connect(sock,
+		     (struct sockaddr *) &server,
 		     sizeof(server)) < 0) {
       if (errno != EINPROGRESS) {
-	log_err(errno, "could not connect to %s:%d", 
-		inet_ntoa(server.sin_addr), port);
+	syslog(LOG_ERR, "%d could not connect to %s:%d",
+               errno, inet_ntoa(server.sin_addr), port);
 	close(sock);
 	return -1;
       }
@@ -58,7 +57,7 @@ int conn_sock(struct conn_t *conn, struct in_addr *addr, int port) {
   return 0;
 }
 
-int conn_setup(struct conn_t *conn, char *hostname, 
+int conn_setup(struct conn_t *conn, char *hostname,
 	       int port, bstring bwrite, bstring bread) {
   struct hostent *host;
 
@@ -68,8 +67,8 @@ int conn_setup(struct conn_t *conn, char *hostname,
   conn->read_buf = bread;
 
   if (!(host = gethostbyname(hostname)) || !host->h_addr_list[0]) {
-    log_err(0, "Could not resolve IP address of uamserver: %s! [%s]", 
-	    hostname, strerror(errno));
+    syslog(LOG_ERR, "Could not resolve IP address of uamserver: %s! [%s]",
+           hostname, strerror(errno));
     return -1;
   }
 
@@ -95,7 +94,7 @@ int conn_select_fd(struct conn_t *conn, select_ctx *sctx) {
   int evts = SELECT_READ;
   if (!conn->sock) return -1;
   if (conn->write_buf &&
-      conn->write_pos < conn->write_buf->slen) 
+      conn->write_pos < conn->write_buf->slen)
     evts |= SELECT_WRITE;
   net_select_modfd(sctx, conn->sock, evts);
   return net_select_fd(sctx, conn->sock, evts);
@@ -111,15 +110,15 @@ void conn_finish(struct conn_t *conn) {
 
 int conn_update_write(struct conn_t *conn) {
 #if(_debug_)
-  log_dbg("socket writeable!");
+  syslog(LOG_DEBUG, "%s(%d): socket writeable!", __FUNCTION__, __LINE__);
 #endif
-  
+
   if (conn->write_pos == 0) {
     int err;
     socklen_t errlen = sizeof(err);
-    if (getsockopt(conn->sock, SOL_SOCKET, SO_ERROR, 
+    if (getsockopt(conn->sock, SOL_SOCKET, SO_ERROR,
 		   &err, &errlen) || (err != 0)) {
-      log_err(errno, "not connected");
+      syslog(LOG_ERR, "%s: not connected", strerror(errno));
       conn_finish(conn);
       return -1;
     } else {
@@ -127,13 +126,13 @@ int conn_update_write(struct conn_t *conn) {
       /*log_dbg("RESETTING non-blocking");*/
 #endif
       /*if (ndelay_off(conn->sock) < 0) {
-	log_err(errno, "could not un-set non-blocking");
+	syslog(LOG_ERR, "%s: could not un-set non-blocking", strerror(errno));
 	}*/
     }
   }
-  
+
   if (conn->write_pos < conn->write_buf->slen) {
-    int ret = net_write(conn->sock, 
+    int ret = net_write(conn->sock,
 			conn->write_buf->data + conn->write_pos,
 			conn->write_buf->slen - conn->write_pos);
     if (ret > 0) {
@@ -141,34 +140,34 @@ int conn_update_write(struct conn_t *conn) {
       conn->write_pos += ret;
     } else if (ret < 0 || errno != EWOULDBLOCK) {
 #if(_debug_)
-      log_dbg("socket closed!");
+      syslog(LOG_DEBUG, "%s(%d): socket closed!", __FUNCTION__, __LINE__);
 #endif
       conn_finish(conn);
       return -1;
     }
-  } 
-  
+  }
+
   return 0;
 }
 
 int conn_select_update(struct conn_t *conn, select_ctx *sctx) {
   if (conn->sock) {
     switch (net_select_read_fd(sctx, conn->sock)) {
-    case -1:
-      log_dbg("exception");
-      conn_finish(conn);
-      return -1;
-      
-    case 1:
-      if (conn->read_handler)
-	conn->read_handler(conn, conn->read_handler_ctx);
-      break;
+      case -1:
+        syslog(LOG_DEBUG, "%s(%d): exception", __FUNCTION__, __LINE__);
+        conn_finish(conn);
+        return -1;
+
+      case 1:
+        if (conn->read_handler)
+          conn->read_handler(conn, conn->read_handler_ctx);
+        break;
     }
-    
+
     if (net_select_write_fd(sctx, conn->sock)==1)
       conn_update_write(conn);
   }
-  
+
   return 0;
 }
 
@@ -187,7 +186,7 @@ int conn_update(struct conn_t *conn, fd_set *r, fd_set *w, fd_set *e) {
 
     if (FD_ISSET(conn->sock, e)) {
 #if(_debug_)
-      log_dbg("socket exception!");
+      syslog(LOG_DEBUG, "%s(%d): socket exception!", __FUNCTION__, __LINE__);
 #endif
       conn_finish(conn);
     }
@@ -196,25 +195,25 @@ int conn_update(struct conn_t *conn, fd_set *r, fd_set *w, fd_set *e) {
   return 0;
 }
 
-static int 
+static int
 _conn_bstring_readhandler(struct conn_t *conn, void *ctx) {
   bstring data = (bstring)ctx;
   int ret;
   ballocmin(data, data->slen + 128);
 
-  ret = safe_read(conn->sock, 
+  ret = safe_read(conn->sock,
 		  data->data + data->slen,
 		  data->mlen - data->slen);
 
   if (ret > 0) {
 #if(_debug_)
-    log_dbg("bstring_read: %d bytes", ret);
+    syslog(LOG_DEBUG, "%s(%d): bstring_read: %d bytes", __FUNCTION__, __LINE__, ret);
 #endif
     data->slen += ret;
   } else {
 #if(_debug_)
-    log_dbg("socket closed!");
-    log_dbg("<== [%s]", data->data);
+    syslog(LOG_DEBUG, "%s(%d): socket closed!", __FUNCTION__, __LINE__);
+    syslog(LOG_DEBUG, "%s(%d): <== [%s]", __FUNCTION__, __LINE__, data->data);
 #endif
     conn_finish(conn);
   }
@@ -238,7 +237,7 @@ void conn_set_donehandler(struct conn_t *conn, conn_handler handler, void *ctx)
 }
 
 int conn_close(struct conn_t *conn) {
-  if (conn->sock) 
+  if (conn->sock)
     close(conn->sock);
 #ifdef HAVE_SSL
   if (conn->sslcon) {
