@@ -1,21 +1,21 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2003, 2004, 2005 Mondru AB.
  * Copyright (C) 2007-2012 David Bird (Coova Technologies) <support@coova.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef _DHCP_H
@@ -37,6 +37,7 @@
 #define DHCP_OPTION_DOMAIN_NAME    15
 #define DHCP_OPTION_INTERFACE_MTU  26
 #define DHCP_OPTION_STATIC_ROUTES  33
+#define DHCP_OPTION_VENDOR_SPECIFIC_INFORMATION 43
 #define DHCP_OPTION_REQUESTED_IP   50
 #define DHCP_OPTION_LEASE_TIME     51
 #define DHCP_OPTION_MESSAGE_TYPE   53
@@ -46,6 +47,7 @@
 #define DHCP_OPTION_CLIENT_IDENTIFIER 61
 #define DHCP_OPTION_CLIENT_FQDN    81
 #define DHCP_OPTION_82    82
+#define DHCP_OPTION_CAPTIVE_PORTAL_URI 160
 
 /* !!highly experimental!! */
 #define DHCP_OPTION_CALLED_STATION_ID  197
@@ -161,7 +163,7 @@ struct dhcp_conn_t {
   int lanidx;
 #else
 #define dhcp_conn_idx(x) 0
-#define dhcp_conn_set_idx(x,c) 
+#define dhcp_conn_set_idx(x,c)
 #endif
 
 #ifdef ENABLE_IPV6
@@ -188,8 +190,8 @@ struct dhcp_conn_t {
  * Information storage for each dhcp instance
  *
  * Normally each instance of the application corresponds to
- * one instance of a dhcp instance. 
- * 
+ * one instance of a dhcp instance.
+ *
  *************************************************************/
 
 struct dhcp_t {
@@ -198,13 +200,13 @@ struct dhcp_t {
   struct _net_interface rawif[MAX_RAWIF];
 
 #ifdef HAVE_NETFILTER_QUEUE
-  struct _net_interface qif_in; 
-  struct _net_interface qif_out; 
+  struct _net_interface qif_in;
+  struct _net_interface qif_out;
 #endif
 
   int numconn;          /* Maximum number of connections */
 
-#if defined (__FreeBSD__) || defined (__APPLE__) || defined (__OpenBSD__)
+#if defined (__FreeBSD__) || defined (__APPLE__) || defined (__OpenBSD__) || defined (__NetBSD__)
   struct pkt_buffer pb;
 #endif
 
@@ -259,7 +261,8 @@ struct dhcp_t {
   /* Call back functions */
   int (*cb_data_ind) (struct dhcp_conn_t *conn, uint8_t *pack, size_t len);
   int (*cb_eap_ind)  (struct dhcp_conn_t *conn, uint8_t *pack, size_t len);
-  int (*cb_request) (struct dhcp_conn_t *conn, struct in_addr *addr, uint8_t *pack, size_t len);
+  int (*cb_request) (struct dhcp_conn_t *conn, struct in_addr *addr,
+                     uint8_t *pack, size_t len);
   int (*cb_connect) (struct dhcp_conn_t *conn);
   int (*cb_disconnect) (struct dhcp_conn_t *conn, int term_cause);
 };
@@ -268,9 +271,9 @@ struct dhcp_t {
 const char* dhcp_version();
 
 int dhcp_new(struct dhcp_t **dhcp, int numconn, int hashsize,
-	     char *interface, int usemac, uint8_t *mac, int promisc, 
+	     char *interface, int usemac, uint8_t *mac, int promisc,
 	     struct in_addr *listen, int lease, int allowdyn,
-	     struct in_addr *uamlisten, uint16_t uamport, 
+	     struct in_addr *uamlisten, uint16_t uamport,
 	     int noc2c);
 
 int dhcp_set(struct dhcp_t *dhcp, char *ethers, int debug);
@@ -281,14 +284,14 @@ int dhcp_timeout(struct dhcp_t *this);
 
 int dhcp_send(struct dhcp_t *this, int idx,
 	      unsigned char *hismac, uint8_t *packet, size_t length);
-int dhcp_net_send(struct _net_interface *netif, unsigned char *hismac, 
+int dhcp_net_send(struct _net_interface *netif, unsigned char *hismac,
 		  uint8_t *packet, size_t length);
 
 struct timeval * dhcp_timeleft(struct dhcp_t *this, struct timeval *tvp);
 
 int dhcp_validate(struct dhcp_t *this);
 
-int dhcp_set_addrs(struct dhcp_conn_t *conn, 
+int dhcp_set_addrs(struct dhcp_conn_t *conn,
 		   struct in_addr *hisip, struct in_addr *hismask,
 		   struct in_addr *ourip, struct in_addr *ourmask,
 		   struct in_addr *dns1, struct in_addr *dns2);
@@ -299,25 +302,29 @@ int dhcp_relay_decaps(struct dhcp_t *this, int idx);
 int dhcp_data_req(struct dhcp_conn_t *conn, struct pkt_buffer *pb, int ethhdr);
 uint8_t * dhcp_nexthop(struct dhcp_t *);
 
-#if defined (__FreeBSD__) || defined (__APPLE__) || defined (__OpenBSD__)
+#if defined (__FreeBSD__) || defined (__APPLE__) || defined (__OpenBSD__) || defined (__NetBSD__)
 int dhcp_receive(struct dhcp_t *this, int idx);
 #endif
 
-int dhcp_set_cb_data_ind(struct dhcp_t *this, 
-  int (*cb_data_ind) (struct dhcp_conn_t *conn, uint8_t *pack, size_t len));
+int dhcp_set_cb_data_ind(struct dhcp_t *this,
+                         int (*cb_data_ind) (struct dhcp_conn_t *conn,
+                                             uint8_t *pack, size_t len));
 
-int dhcp_set_cb_request(struct dhcp_t *this, 
-  int (*cb_request) (struct dhcp_conn_t *conn, 
-		     struct in_addr *addr, uint8_t *pack, size_t len));
+int dhcp_set_cb_request(struct dhcp_t *this,
+                        int (*cb_request) (struct dhcp_conn_t *conn,
+                                           struct in_addr *addr,
+                                           uint8_t *pack, size_t len));
 
-int dhcp_set_cb_disconnect(struct dhcp_t *this, 
-  int (*cb_disconnect) (struct dhcp_conn_t *conn, int term_cause));
+int dhcp_set_cb_disconnect(struct dhcp_t *this,
+                           int (*cb_disconnect) (struct dhcp_conn_t *conn,
+                                                 int term_cause));
 
-int dhcp_set_cb_connect(struct dhcp_t *this, 
-  int (*cb_connect) (struct dhcp_conn_t *conn));
+int dhcp_set_cb_connect(struct dhcp_t *this,
+                        int (*cb_connect) (struct dhcp_conn_t *conn));
 
-int dhcp_set_cb_eap_ind(struct dhcp_t *this, 
-  int (*cb_eap_ind) (struct dhcp_conn_t *conn, uint8_t *pack, size_t len));
+int dhcp_set_cb_eap_ind(struct dhcp_t *this,
+                        int (*cb_eap_ind) (struct dhcp_conn_t *conn,
+                                           uint8_t *pack, size_t len));
 
 int dhcp_hashget(struct dhcp_t *this, struct dhcp_conn_t **conn, uint8_t *hwaddr);
 
