@@ -1,21 +1,21 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2007-2013 David Bird (Coova Technologies) <support@coova.com>
  * Copyright (C) 2003, 2004, 2005 Mondru AB.
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef _OPTIONS_H
@@ -28,6 +28,8 @@ struct options_t {
   int initialized;
   int foreground;
   int debug;
+  int logfacility;
+  int loglevel;
   /* conf */
   uid_t uid;
   gid_t gid;
@@ -87,10 +89,10 @@ struct options_t {
   char* radiussecret;            /* Radius shared secret */
 
 #ifdef ENABLE_LARGELIMITS
-  struct in_addr radiusacctserver1; 
-  struct in_addr radiusacctserver2; 
-  struct in_addr radiusadmserver1;  
-  struct in_addr radiusadmserver2;  
+  struct in_addr radiusacctserver1;
+  struct in_addr radiusacctserver2;
+  struct in_addr radiusadmserver1;
+  struct in_addr radiusadmserver2;
   char* radiusacctsecret;
   char* radiusadmsecret;
 #endif
@@ -104,7 +106,6 @@ struct options_t {
   int radiusnasporttype;         /* NAS-Port-Type */
   uint16_t coaport;              /* UDP port to listen to */
   int coanoipcheck;              /* Allow disconnect from any IP */
-  int logfacility;
   int radiustimeout;             /* Retry timeout in milli seconds */
   int radiusretry;               /* Total amount of retries */
   int radiusretrysec;            /* Amount of retries after we switch to secondary */
@@ -216,7 +217,7 @@ struct options_t {
   uint8_t macreauth:1;              /* Use MAC re-authentication on /prelogin */
   uint8_t macauthdeny:1;            /* Deny any access to those given Access-Reject */
   uint8_t macallowlocal:1;          /* Do not use RADIUS for authenticating the macallowed */
-  uint8_t radiusoriginalurl:1;      /* Send ChilliSpot-OriginalURL in AccessRequest */
+  uint8_t radiusoriginalurl:1;      /* Send CoovaChilli-OriginalURL in AccessRequest */
   uint8_t dhcpradius:1;             /* Send certain DHCP options in RADIUS attributes */
   uint8_t has_nexthop:1;            /* Has a nexthop entry */
   uint8_t dhcp_broadcast:1;         /* always broadcast DHCP (when not relaying) */
@@ -238,6 +239,7 @@ struct options_t {
   uint8_t dhcpnotidle:1;
   uint8_t uamauthedallowed:1;
   uint8_t postauth_proxyssl:1;
+  uint8_t nochallenge:1;
 
 #ifdef USING_MMAP
   uint8_t mmapring:1;
@@ -272,7 +274,7 @@ struct options_t {
   uint8_t proxymacaccept:1;         /* Auto-accept non-EAP requests on proxy port */
   uint8_t proxyonacct:1;
 #endif
-#ifdef ENABLE_PROXYVSA
+#if defined(ENABLE_LOCATION) || defined(ENABLE_PROXYVSA)
   uint8_t vlanlocation:1;
   uint8_t location_stop_start:1;
   uint8_t location_copy_called:1;
@@ -320,6 +322,8 @@ struct options_t {
   uint32_t ipsrc_num_pass_throughs;
 #endif
 
+  char* rfc7710uri; /* RFC 7710 URI, nullptr if not used. */
+
   char* uamdomains[MAX_UAM_DOMAINS];
   int uamdomain_ttl;
 
@@ -327,7 +331,7 @@ struct options_t {
   uint8_t macok[MACOK_MAX][PKT_ETH_ALEN]; /* Allowed MACs */
   int macoklen;                   /* Number of MAC addresses */
   char* macsuffix;               /* Suffix to add to MAC address */
-  char* macpasswd;               /* Password to use for MAC authentication */  
+  char* macpasswd;               /* Password to use for MAC authentication */
 
   uint64_t defsessiontimeout;
   uint64_t defbandwidthmaxdown;
@@ -338,7 +342,7 @@ struct options_t {
   uint32_t challengetimeout;
   uint32_t challengetimeout2;
 
-#ifdef ENABLE_PROXYVSA
+#if defined(ENABLE_LOCATION) || defined(ENABLE_PROXYVSA)
 #define PROXYVSA_ATTR_CNT 4
   struct {
     uint32_t attr_vsa;
@@ -352,6 +356,7 @@ struct options_t {
   char *sslkeypass;
   char *sslcertfile;
   char *sslcafile;
+  char *sslciphers;
 #endif
 
   /* local content */
@@ -377,10 +382,6 @@ struct options_t {
   int dhcp_options_len;
 #endif
 
-#ifdef ENABLE_DNSLOG
-  char *dnslog;
-#endif
-
 #ifdef ENABLE_IPWHITELIST
   char *ipwhitelist;
 #endif
@@ -436,9 +437,9 @@ int process_options(int argc, char **argv, int minimal);
 void reprocess_options(int argc, char **argv);
 int reload_options(int argc, char **argv);
 int options_save(char *file, bstring bt);
-void options_init();
-void options_destroy();
-void options_cleanup();
+void options_init(void);
+void options_destroy(void);
+void options_cleanup(void);
 
 #ifndef MAIN_FILE /* all main() files must implement _options */
 extern struct options_t _options;
