@@ -1,20 +1,20 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2007-2012 David Bird (Coova Technologies) <support@coova.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #include "system.h"
@@ -47,9 +47,9 @@ struct netlink_req {
 static int open_netlink() {
   int sock = socket(AF_NETLINK, SOCK_RAW, MYPROTO);
   struct sockaddr_nl addr;
-  
+
   memset((void *)&addr, 0, sizeof(addr));
-  
+
   if (sock<0)
     return sock;
 
@@ -57,8 +57,11 @@ static int open_netlink() {
   addr.nl_pid = getpid();
   addr.nl_groups = MYMGRP;
 
-  if (bind(sock,(struct sockaddr *)&addr,sizeof(addr)) < 0)
+  if (bind(sock,(struct sockaddr *)&addr,sizeof(addr)) < 0) {
+    syslog(LOG_ERR, "Binding on socket(%d) failed.", sock);
+    close(sock);
     return -1;
+  }
 
   return sock;
 }
@@ -73,12 +76,12 @@ int rtmon_init(struct rtmon_t *rtmon, rtmon_callback func) {
 
     rtmon_discover_ifaces(rtmon);
     rtmon_discover_routes(rtmon);
-    
+
     if (_options.debug) {
       rtmon_print_ifaces(rtmon, 1);
       rtmon_print_routes(rtmon, 1);
     }
-    
+
     rtmon_check_updates(rtmon);
     return 0;
   }
@@ -87,7 +90,7 @@ int rtmon_init(struct rtmon_t *rtmon, rtmon_callback func) {
 
 static int netlink_route_request(int fd) {
   struct sockaddr_nl local;
-  struct sockaddr_nl peer;   
+  struct sockaddr_nl peer;
   struct msghdr msg_info;
   struct netlink_req req;
   struct iovec iov_info;
@@ -103,31 +106,31 @@ static int netlink_route_request(int fd) {
     perror("bind");
     return -1;
   }
-  
+
   bzero(&peer, sizeof(peer));
   peer.nl_family = AF_NETLINK;
   peer.nl_pad = 0;
   peer.nl_pid = 0;
   peer.nl_groups = 0;
-  
+
   bzero(&msg_info, sizeof(msg_info));
   msg_info.msg_name = (void *) &peer;
   msg_info.msg_namelen = sizeof(peer);
-  
+
   bzero(&req, sizeof(req));
-  
+
   req.nlmsg_info.nlmsg_len = NLMSG_LENGTH(sizeof(struct rtmsg));
   req.nlmsg_info.nlmsg_flags = NLM_F_REQUEST | NLM_F_DUMP;
   req.nlmsg_info.nlmsg_type = RTM_GETROUTE;
-  
+
   req.rtmsg_info.rtm_family = AF_INET;
   req.rtmsg_info.rtm_table = RT_TABLE_MAIN;
-  
+
   iov_info.iov_base = (void *) &req.nlmsg_info;
   iov_info.iov_len = req.nlmsg_info.nlmsg_len;
   msg_info.msg_iov = &iov_info;
   msg_info.msg_iovlen = 1;
-  
+
   rtn = safe_sendmsg(fd, &msg_info, 0);
 
   if (rtn < 0) {
@@ -148,7 +151,7 @@ static int netlink_route_results(int fd, char *b, size_t blen) {
     int rtn = safe_recv(fd, b, left, 0);
 
     struct nlmsghdr *hdr = (struct nlmsghdr *) b;
-    
+
     if (rtn <= 0) {
       perror("recv");
       break;
@@ -175,7 +178,7 @@ static int rtmon_add_route(struct rtmon_t *rtmon, struct rtmon_route *rt) {
 
   for (i=0; i < sz; i++) {
     if (!memcmp(&rtmon->_routes[i], rt, sizeof(struct rtmon_route))) {
-      log_dbg("Already have this route for %s", inet_ntoa(rt->destination));
+      syslog(LOG_DEBUG, "Already have this route for %s", inet_ntoa(rt->destination));
       return 0;
     }
     if (!dst && !rtmon->_routes[i].has_data) {
@@ -185,13 +188,13 @@ static int rtmon_add_route(struct rtmon_t *rtmon, struct rtmon_route *rt) {
 
   if (!dst) {
     if (sz) {
-      rtmon->_routes = 
-	(struct rtmon_route *)realloc(rtmon->_routes, 
-				      (sz + 1) * sizeof(struct rtmon_route));
+      rtmon->_routes =
+          (struct rtmon_route *)realloc(rtmon->_routes,
+                                        (sz + 1) * sizeof(struct rtmon_route));
       dst = &rtmon->_routes[sz];
     } else {
-      dst = rtmon->_routes = 
-	(struct rtmon_route *)malloc(sizeof(struct rtmon_route));
+      dst = rtmon->_routes =
+          (struct rtmon_route *)malloc(sizeof(struct rtmon_route));
     }
 
     rtmon->_route_sz++;
@@ -203,8 +206,8 @@ static int rtmon_add_route(struct rtmon_t *rtmon, struct rtmon_route *rt) {
 }
 
 /**
-* Extract each route table entry and print
-*/
+ * Extract each route table entry and print
+ */
 static void netlink_parse_routes(struct rtmon_t *rtmon, char *b, int blen) {
   struct nlmsghdr *hdr = (struct nlmsghdr *) b;
   struct rtattr * attr;
@@ -224,16 +227,16 @@ static void netlink_parse_routes(struct rtmon_t *rtmon, char *b, int blen) {
 
     for (;RTA_OK(attr, payload); attr = RTA_NEXT(attr, payload)) {
       switch(attr->rta_type) {
-      case RTA_DST:
-	rt.destination = *(struct in_addr *)RTA_DATA(attr);
-	break;
-      case RTA_GATEWAY:
-	rt.gateway = *(struct in_addr *)RTA_DATA(attr);
-	break;
-      case RTA_OIF:
-	rt.if_index = *((int *) RTA_DATA(attr));
-      default:
-	break; 
+        case RTA_DST:
+          rt.destination = *(struct in_addr *)RTA_DATA(attr);
+          break;
+        case RTA_GATEWAY:
+          rt.gateway = *(struct in_addr *)RTA_DATA(attr);
+          break;
+        case RTA_OIF:
+          rt.if_index = *((int *) RTA_DATA(attr));
+        default:
+          break;
       }
     }
 
@@ -274,15 +277,15 @@ static char *lookup_name(struct msgnames_t *db, int id) {
   if (msgnamesiter->msg) {
     return msgnamesiter->msg;
   }
-  safe_snprintf(name,sizeof(name),"#%i\n",id);
+  snprintf(name,sizeof(name),"#%i\n",id);
   return name;
 }
 
 static char * idx2name(struct rtmon_t *rtmon, int idx) {
   int i;
 
-  for (i=0; i<rtmon->_iface_sz; i++) 
-    if (rtmon->_ifaces[i].has_data) 
+  for (i=0; i<rtmon->_iface_sz; i++)
+    if (rtmon->_ifaces[i].has_data)
       if (rtmon->_ifaces[i].index == idx)
 	return rtmon->_ifaces[i].devname;
 
@@ -292,8 +295,8 @@ static char * idx2name(struct rtmon_t *rtmon, int idx) {
 struct rtmon_iface * rtmon_find(struct rtmon_t *rtmon, char *name) {
   int i;
 
-  for (i=0; i<rtmon->_iface_sz; i++) 
-    if (rtmon->_ifaces[i].has_data) 
+  for (i=0; i<rtmon->_iface_sz; i++)
+    if (rtmon->_ifaces[i].has_data)
       if (!strcmp(rtmon->_ifaces[i].devname, name))
 	return &rtmon->_ifaces[i];
 
@@ -304,44 +307,44 @@ void rtmon_print_ifaces(struct rtmon_t *rtmon, int fd) {
   char line[512];
   int i;
 
-  safe_snprintf(line,512,"\nSystem Interfaces\n");
+  snprintf(line,512,"\nSystem Interfaces\n");
   safe_write(fd, line, strlen(line));
-  
+
   for (i=0; i < rtmon->_iface_sz; i++) {
 
     if (rtmon->_ifaces[i].has_data) {
       unsigned char *u = rtmon->_ifaces[i].hwaddr;
 
-      safe_snprintf(line,512,"%d) %s (%d)", 
+      snprintf(line,512,"%d) %s (%d)",
 		    i, rtmon->_ifaces[i].devname, rtmon->_ifaces[i].index);
       safe_write(fd, line, strlen(line));
 
       if (rtmon->_ifaces[i].address.s_addr) {
-	safe_snprintf(line,512," ip=%s", inet_ntoa(rtmon->_ifaces[i].address));
+	snprintf(line,512," ip=%s", inet_ntoa(rtmon->_ifaces[i].address));
 	safe_write(fd, line, strlen(line));
       }
 
-      safe_snprintf(line,512," net=%s", inet_ntoa(rtmon->_ifaces[i].network));
+      snprintf(line,512," net=%s", inet_ntoa(rtmon->_ifaces[i].network));
       safe_write(fd, line, strlen(line));
 
-      safe_snprintf(line,512," mask=%s", inet_ntoa(rtmon->_ifaces[i].netmask));
+      snprintf(line,512," mask=%s", inet_ntoa(rtmon->_ifaces[i].netmask));
       safe_write(fd, line, strlen(line));
 
       if (rtmon->_ifaces[i].broadcast.s_addr) {
-	safe_snprintf(line,512," bcase=%s", inet_ntoa(rtmon->_ifaces[i].broadcast));
+	snprintf(line,512," bcase=%s", inet_ntoa(rtmon->_ifaces[i].broadcast));
 	safe_write(fd, line, strlen(line));
       }
 
       if (rtmon->_ifaces[i].gateway.s_addr) {
-	safe_snprintf(line,512," peer=%s", inet_ntoa(rtmon->_ifaces[i].gateway));
+	snprintf(line,512," peer=%s", inet_ntoa(rtmon->_ifaces[i].gateway));
 	safe_write(fd, line, strlen(line));
       }
 
-      safe_snprintf(line,512," mac=%2.2X-%2.2X-%2.2X-%2.2X-%2.2X-%2.2x",
+      snprintf(line,512," mac=%2.2X-%2.2X-%2.2X-%2.2X-%2.2X-%2.2x",
 		    u[0], u[1], u[2], u[3], u[4], u[5]);
       safe_write(fd, line, strlen(line));
 
-      safe_snprintf(line,512," mtu=%u\n",  rtmon->_ifaces[i].mtu);
+      snprintf(line,512," mtu=%u\n",  rtmon->_ifaces[i].mtu);
       safe_write(fd, line, strlen(line));
     }
   }
@@ -351,20 +354,20 @@ void rtmon_print_routes(struct rtmon_t *rtmon, int fd) {
   char line[512];
   int i;
 
-  safe_snprintf(line,512,"\nSystem Routes\n");
+  snprintf(line,512,"\nSystem Routes\n");
   safe_write(fd, line, strlen(line));
 
   for (i=0; i < rtmon->_route_sz; i++) {
     if (rtmon->_routes[i].has_data) {
-      safe_snprintf(line,512,"%d) dst=%s", i, inet_ntoa(rtmon->_routes[i].destination));
+      snprintf(line,512,"%d) dst=%s", i, inet_ntoa(rtmon->_routes[i].destination));
       safe_write(fd, line, strlen(line));
-      safe_snprintf(line,512," mask=%s", inet_ntoa(rtmon->_routes[i].netmask));
+      snprintf(line,512," mask=%s", inet_ntoa(rtmon->_routes[i].netmask));
       safe_write(fd, line, strlen(line));
       if (rtmon->_routes[i].gateway.s_addr) {
-	safe_snprintf(line,512," gw=%s", inet_ntoa(rtmon->_routes[i].gateway));
+	snprintf(line,512," gw=%s", inet_ntoa(rtmon->_routes[i].gateway));
 	safe_write(fd, line, strlen(line));
       }
-      safe_snprintf(line,512," dev=%s (%d)\n", idx2name(rtmon, rtmon->_routes[i].if_index), rtmon->_routes[i].if_index);
+      snprintf(line,512," dev=%s (%d)\n", idx2name(rtmon, rtmon->_routes[i].if_index), rtmon->_routes[i].if_index);
       safe_write(fd, line, strlen(line));
     }
   }
@@ -372,7 +375,7 @@ void rtmon_print_routes(struct rtmon_t *rtmon, int fd) {
 
 static const char *mactoa(uint8_t *m) {
   static char buff[256];
-  safe_snprintf(buff, sizeof(buff), 
+  snprintf(buff, sizeof(buff),
 		"%02x:%02x:%02x:%02x:%02x:%02x",
 		m[0], m[1], m[2], m[3], m[4], m[5]);
   return (buff);
@@ -384,7 +387,7 @@ void rtmon_check_updates(struct rtmon_t *rtmon) {
     if (rtmon->_routes[i].has_data) {
       if (rtmon->_routes[i].destination.s_addr == 0) {
 
-	log_dbg("Default Route %s", inet_ntoa(rtmon->_routes[i].gateway));
+	syslog(LOG_DEBUG, "Default Route %s", inet_ntoa(rtmon->_routes[i].gateway));
 
 	for (j=0; j < rtmon->_iface_sz; j++) {
 	  if (rtmon->_ifaces[j].has_data) {
@@ -392,8 +395,8 @@ void rtmon_check_updates(struct rtmon_t *rtmon) {
 	      struct arpreq areq;
 	      struct sockaddr_in *sin;
 	      int s, attempt=0, retries=3;
-	      
-	      log_dbg("Route Interface %s", rtmon->_ifaces[j].devname);
+
+	      syslog(LOG_DEBUG, "Route Interface %s", rtmon->_ifaces[j].devname);
 
 	      if ((s = socket(AF_INET, SOCK_DGRAM, 0)) == -1) {
 		perror("socket");
@@ -406,26 +409,26 @@ void rtmon_check_updates(struct rtmon_t *rtmon) {
 	      sin->sin_family = AF_INET;
 	      sin->sin_addr.s_addr = rtmon->_routes[i].gateway.s_addr;
 
-	      safe_strncpy(areq.arp_dev, rtmon->_ifaces[j].devname, sizeof(areq.arp_dev));
+	      strlcpy(areq.arp_dev, rtmon->_ifaces[j].devname, sizeof(areq.arp_dev));
 
 	      while (attempt < retries) {
 		struct sockaddr_in addr;
 		char b[1]={0};
-		
+
 		memset(&addr, 0, sizeof(addr));
 		addr.sin_family = AF_INET;
 		addr.sin_addr = sin->sin_addr;
 		addr.sin_port = htons(10000);
-		
+
 		if (sendto(s, b, sizeof(b), 0,
-			   (struct sockaddr *) &addr, 
+			   (struct sockaddr *) &addr,
 			   sizeof(addr)) < 0)
 		  perror("sendto");
 
 		if (ioctl(s, SIOCGARP, (caddr_t) &areq) == -1) {
 
 		  if (errno == ENXIO) {
-		    log_dbg("%s -- no entry\n", inet_ntoa(sin->sin_addr));
+		    syslog(LOG_DEBUG, "%s -- no entry\n", inet_ntoa(sin->sin_addr));
 		    attempt++;
 		    sleep(1);
 		    continue;
@@ -434,11 +437,11 @@ void rtmon_check_updates(struct rtmon_t *rtmon) {
 
 		} else {
 
-		  log_dbg("MAC %s", mactoa((uint8_t *)&areq.arp_ha.sa_data));
+		  syslog(LOG_DEBUG, "MAC %s", mactoa((uint8_t *)&areq.arp_ha.sa_data));
 		  memcpy(rtmon->_routes[i].gwaddr, &areq.arp_ha.sa_data, sizeof(rtmon->_routes[i].gwaddr));
 
 		  if (rtmon->cb(rtmon, &rtmon->_ifaces[j], &rtmon->_routes[i]))
-		    log_err(errno, "callback failed");
+		    syslog(LOG_ERR, "%s: callback failed", strerror(errno));
 
 		  break;
 		}
@@ -462,10 +465,10 @@ static int rtmon_add_iface(struct rtmon_t *rtmon, struct rtmon_iface *ri) {
   ri->has_data = 1 | RTMON_REMOVE;
 
   for (i=0; i < sz; i++) {
-    log_dbg("i=%d sz=%d",i,sz);
+    syslog(LOG_DEBUG, "i=%d sz=%d",i,sz);
     if (!memcmp(&rtmon->_ifaces[i], ri, sizeof(struct rtmon_iface))) {
       rtmon->_ifaces[i].has_data = 1;
-      log_dbg("Already have this iface %s", ri->devname);
+      syslog(LOG_DEBUG, "Already have this iface %s", ri->devname);
       return 0;
     }
     if (!dst && !rtmon->_ifaces[i].has_data) {
@@ -476,13 +479,13 @@ static int rtmon_add_iface(struct rtmon_t *rtmon, struct rtmon_iface *ri) {
   if (!dst) {
 
     if (sz) {
-      rtmon->_ifaces = 
-	(struct rtmon_iface *)realloc(rtmon->_ifaces, 
-				      (sz + 1) * sizeof(struct rtmon_iface));
+      rtmon->_ifaces =
+          (struct rtmon_iface *)realloc(rtmon->_ifaces,
+                                        (sz + 1) * sizeof(struct rtmon_iface));
       dst = &rtmon->_ifaces[sz];
     } else {
-      dst = rtmon->_ifaces = 
-	(struct rtmon_iface *)malloc(sizeof(struct rtmon_iface));
+      dst = rtmon->_ifaces =
+          (struct rtmon_iface *)malloc(sizeof(struct rtmon_iface));
     }
 
     rtmon->_iface_sz++;
@@ -503,100 +506,100 @@ void rtmon_discover_ifaces(struct rtmon_t *rtmon) {
   for (i=0; i < rtmon->_iface_sz; i++)
     if (rtmon->_ifaces[i].has_data)
       rtmon->_ifaces[i].has_data |= RTMON_REMOVE;
-  
+
   if ((fd = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
     return;
   }
-  
+
   ic.ifc_buf=0;
   ic.ifc_len=0;
-    
+
   if (ioctl(fd, SIOCGIFCONF, &ic) < 0) {
     close(fd);
     return;
   }
-  
+
   ic.ifc_buf = calloc((size_t)ic.ifc_len, 1);
   if (ioctl(fd, SIOCGIFCONF, &ic) < 0) {
     close(fd);
     free(ic.ifc_buf);
     return;
   }
-  
+
   len = (ic.ifc_len/sizeof(struct ifreq));
-  
+
   for (i=0; i < len; ++i) {
     struct ifreq *ifr = (struct ifreq *)&ic.ifc_req[i];
 
     memset(&ri, 0, sizeof(ri));
-    
+
     /* device name and address */
-    safe_strncpy(ri.devname, ifr->ifr_name, sizeof(ri.devname));
+    strlcpy(ri.devname, ifr->ifr_name, sizeof(ri.devname));
     ri.address = inaddr(ifr_addr);
-    
+
     /* index */
     if (-1 < ioctl(fd, SIOCGIFINDEX, (caddr_t) ifr)) {
       ri.index = ifr->ifr_ifindex;
     }
-    
+
     /* netmask */
     if (-1 < ioctl(fd, SIOCGIFNETMASK, (caddr_t)ifr)) {
       ri.netmask = inaddr(ifr_addr);
-    } 
-    
+    }
+
     ri.network.s_addr = ri.address.s_addr & ri.netmask.s_addr;
-    
+
     /* hardware address */
 #ifdef SIOCGIFHWADDR
     if (-1 < ioctl(fd, SIOCGIFHWADDR, (caddr_t)ifr)) {
       switch (ifr->ifr_hwaddr.sa_family) {
-      case  ARPHRD_PPP:
-	break;
-      case  ARPHRD_NETROM:  
-      case  ARPHRD_ETHER:  
-      case  ARPHRD_EETHER:  
-      case  ARPHRD_IEEE802: 
-	{
-	  unsigned char *u = (unsigned char *)&ifr->ifr_addr.sa_data;
-	  memcpy(ri.hwaddr, u, 6);
-	}
-	break;
+        case  ARPHRD_PPP:
+          break;
+        case  ARPHRD_NETROM:
+        case  ARPHRD_ETHER:
+        case  ARPHRD_EETHER:
+        case  ARPHRD_IEEE802:
+          {
+            unsigned char *u = (unsigned char *)&ifr->ifr_addr.sa_data;
+            memcpy(ri.hwaddr, u, 6);
+          }
+          break;
       }
-    } 
+    }
 #else
 #ifdef SIOCGENADDR
     if (-1 < ioctl(fd, SIOCGENADDR, (caddr_t)ifr)) {
       unsigned char *u = (unsigned char *)&ifr->ifr_enaddr;
       memcpy(ri.hwaddr, u, 6);
-    } 
+    }
 #else
 #warning Do not know how to find interface hardware address
 #endif /* SIOCGENADDR */
 #endif /* SIOCGIFHWADDR */
-    
-    
+
+
     /* flags */
     if (-1 < ioctl(fd, SIOCGIFFLAGS, (caddr_t)ifr)) {
       ri.devflags = ifr->ifr_flags;
-    } 
-    
+    }
+
     /* point-to-point gateway */
     if (ri.devflags & IFF_POINTOPOINT) {
       if (-1 < ioctl(fd, SIOCGIFDSTADDR, (caddr_t)ifr)) {
 	ri.gateway = inaddr(ifr_addr);
-      } 
+      }
     }
-    
+
     /* broadcast address */
     if (ri.devflags & IFF_BROADCAST) {
       if (-1 < ioctl(fd, SIOCGIFBRDADDR, (caddr_t)ifr)) {
 	ri.broadcast = inaddr(ifr_addr);
-      } 
+      }
     }
-    
+
     if (-1 < ioctl(fd, SIOCGIFMTU, (caddr_t)ifr)) {
       ri.mtu = ifr->ifr_mtu;
-    } 
+    }
 
     rtmon_add_iface(rtmon, &ri);
   }
@@ -604,10 +607,10 @@ void rtmon_discover_ifaces(struct rtmon_t *rtmon) {
   for (i=0; i < rtmon->_iface_sz; i++) {
     if (rtmon->_ifaces[i].has_data & RTMON_REMOVE) {
       tun_delif(tun, rtmon->_ifaces[i].index);
-      memset(&rtmon->_ifaces[i], 0, sizeof(struct rtmon_iface)); 
+      memset(&rtmon->_ifaces[i], 0, sizeof(struct rtmon_iface));
     }
   }
-  
+
   free(ic.ifc_buf);
   close(fd);
 }
@@ -617,18 +620,18 @@ void rtmon_discover_routes(struct rtmon_t *rtmon) {
   char b[8192];
   int blen;
   int i;
-  
+
   fd = socket(AF_NETLINK, SOCK_RAW, NETLINK_ROUTE);
-  
+
   if (fd < 0) {
     perror("Error in sock open");
     return;
   }
-  
+
   if (netlink_route_request(fd) == 0) {
     blen = netlink_route_results(fd, b, sizeof(b));
     netlink_parse_routes(rtmon, b, blen);
-    
+
     for (i=0; i < rtmon->_iface_sz; i++)
       if (rtmon->_ifaces[i].has_data & RTMON_REMOVE)
 	memset(&rtmon->_ifaces[i], 0, sizeof(struct rtmon_iface));
@@ -656,12 +659,12 @@ int rtmon_read_event(struct rtmon_t *rtmon) {
   msg.msg_iovlen = sizeof(iov)/sizeof(iov[0]);
 
   ret = recvmsg(rtmon->fd, &msg, 0);
-  
+
   if (ret < 0) {
     return ret;
   }
 
-  log_dbg("Type: %i (%s)",(nlh.nlmsg_type),lookup_name(typenames,nlh.nlmsg_type));
+  syslog(LOG_DEBUG, "Type: %i (%s)",(nlh.nlmsg_type),lookup_name(typenames,nlh.nlmsg_type));
 
 #define FLAG(x) if (nlh.nlmsg_flags & x) printf(" %s",#x)
   FLAG(NLM_F_REQUEST);
@@ -674,7 +677,7 @@ int rtmon_read_event(struct rtmon_t *rtmon) {
   FLAG(NLM_F_APPEND);
 #undef FLAG
 
-  log_dbg("Seq : %i Pid : %i",nlh.nlmsg_seq,nlh.nlmsg_pid);
+  syslog(LOG_DEBUG, "Seq : %i Pid : %i",nlh.nlmsg_seq,nlh.nlmsg_pid);
 
   rtmon_discover_ifaces(rtmon);
   rtmon_discover_routes(rtmon);
@@ -685,7 +688,7 @@ int rtmon_read_event(struct rtmon_t *rtmon) {
   }
 
   rtmon_check_updates(rtmon);
-  
+
   return 0;
 }
 
