@@ -131,7 +131,7 @@ _openssl_env_init(openssl_env *env, char *engine, int server) {
    */
   const long options = SSL_OP_NO_SSLv2 | SSL_OP_NO_SSLv3 | SSL_OP_NO_COMPRESSION;
   env->meth = SSLv23_method();
-  env->ctx = SSL_CTX_new(env->meth);
+  env->ctx = SSL_CTX_new((void *)env->meth);
   SSL_CTX_set_options(env->ctx, options);
   if (_options.sslciphers) {
     SSL_CTX_set_cipher_list(env->ctx, _options.sslciphers);
